@@ -1,5 +1,5 @@
 /*
- *             Automatically Tuned Linear Algebra Software v3.3.7
+ *             Automatically Tuned Linear Algebra Software v3.3.15
  **************** THIS IS AN UNSUPPORTED DEVELOPER RELEASE *****************
  *                    (C) Copyright 1998 R. Clint Whaley
  *
@@ -11,10 +11,9 @@
  *   2. Redistributions in binary form must reproduce the above copyright
  *      notice, this list of conditions, and the following disclaimer in the
  *      documentation and/or other materials provided with the distribution.
- *   3. The name of the University of Tennessee, the ATLAS group,
- *      or the names of its contributers may not be used to endorse
- *      or promote products derived from this software without specific
- *      written permission.
+ *   3. The name of the ATLAS group or the names of its contributers may
+ *      not be used to endorse or promote products derived from this
+ *      software without specific written permission.
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
@@ -360,7 +359,7 @@ void GoToTown(char *sdir, char *mmdir, int L1DEF)
    int ffetch, ifetch, nfetch;
    int DefInstall=0;
    long imf;
-   int maU, latU, muU, nuU, kuU;
+   int maU, latU, muU, nuU, kuU, il1mul;
    double mfU, mf4x1, mf4x4, mf, mfp, mmmf, mfpeak[2], l1mul;
    FILE *fp, *fpsum;
 
@@ -645,42 +644,28 @@ void GoToTown(char *sdir, char *mmdir, int L1DEF)
       fp = fopen(fnam, "r");
       ATL_Cassert(fp, "MVTUNE", NULL);
       ATL_Cassert(fgets(ln, 256, fp), "MVTUNE", NULL);
-      ATL_Cassert(sscanf(ln, " %d %d %d %lf %lf %s \"%[^\"]", &i, &mu, &nu,
-                         &l1mul, &mf, ln3, tnam) == 7, "MVTUNE", NULL);
-      fprintf(fpsum,
-              "      gemvN : chose routine %s written by %s\n", ln3, tnam);
-      fprintf(fpsum,
-              "              Yunroll=%d, Xunroll=%d, using %5.2f%% of L1\n",
-              mu, nu, l1mul*100.0);
-      fprintf(fpsum,
-"              Performance = %.2f (%5.2f%% of copy matmul, %5.2f%% of peak)\n",
-              mf, (mf/mmmf)*100.0, (mf / mfp)*100.0);
-      fprintf(stdout,
-              "      gemvN : chose routine %s written by %s\n", ln3, tnam);
-      fprintf(stdout,
-              "              Yunroll=%d, Xunroll=%d, using %5.2f%% of L1\n",
-              mu, nu, l1mul*100.0);
-      fprintf(stdout,
+      ATL_Cassert(sscanf(ln, " %d %d %d %d %d %lf %s \"%[^\"]", &j, &i,
+                  &mu, &nu, &il1mul, &mf, ln3, tnam) == 8, "MVTUNE", NULL);
+      ATL_mprintf(2, fpsum, stdout,
+                  "      gemvN : chose routine %d:%s written by %s\n",
+                  j, ln3, tnam);
+      ATL_mprintf(2, fpsum, stdout,
+                  "              Yunroll=%d, Xunroll=%d, using %d%% of L1\n",
+                  mu, nu, il1mul);
+      ATL_mprintf(2, fpsum, stdout,
 "              Performance = %.2f (%5.2f%% of copy matmul, %5.2f%% of peak)\n",
               mf, (mf/mmmf)*100.0, (mf / mfp)*100.0);
       ATL_Cassert(fgets(ln, 256, fp), "MVTUNE", NULL);
-      ATL_Cassert(sscanf(ln, " %d %d %d %lf %lf %s \"%[^\"]", &i, &mu, &nu,
-                         &l1mul, &mf, ln3, tnam) == 7, "MVTUNE", NULL);
+      ATL_Cassert(sscanf(ln, " %d %d %d %d %d %lf %s \"%[^\"]", &j, &i,
+                  &mu, &nu, &il1mul, &mf, ln3, tnam) == 8, "MVTUNE", NULL);
       fclose(fp);
-      fprintf(fpsum,
-              "      gemvT : chose routine %s written by %s\n", ln3, tnam);
-      fprintf(fpsum,
-              "              Yunroll=%d, Xunroll=%d, using %5.2f%% of L1\n",
-              mu, nu, l1mul*100.0);
-      fprintf(fpsum,
-"              Performance = %.2f (%5.2f%% of copy matmul, %5.2f%% of peak)\n",
-              mf, (mf/mmmf)*100.0, (mf / mfp)*100.0);
-      fprintf(stdout,
-              "      gemvT : chose routine %s written by %s\n", ln3, tnam);
-      fprintf(stdout,
-              "              Yunroll=%d, Xunroll=%d, using %5.2f%% of L1\n",
-              mu, nu, l1mul*100.0);
-      fprintf(stdout,
+      ATL_mprintf(2, fpsum, stdout,
+                  "      gemvT : chose routine %d:%s written by %s\n",
+                  j, ln3, tnam);
+      ATL_mprintf(2, fpsum, stdout,
+                  "              Yunroll=%d, Xunroll=%d, using %d%% of L1\n",
+                  mu, nu, il1mul);
+      ATL_mprintf(2, fpsum, stdout,
 "              Performance = %.2f (%5.2f%% of copy matmul, %5.2f%% of peak)\n",
               mf, (mf/mmmf)*100.0, (mf / mfp)*100.0);
 
@@ -699,23 +684,15 @@ void GoToTown(char *sdir, char *mmdir, int L1DEF)
       fp = fopen(fnam, "r");
       ATL_Cassert(fp, "R1TUNE", NULL);
       ATL_Cassert(fgets(ln, 256, fp), "R1TUNE", NULL);
-      ATL_Cassert(sscanf(ln, " %d %d %d %lf %lf %s \"%[^\"]", &i, &mu, &nu,
-                         &l1mul, &mf, ln3, tnam) == 7, "R1TUNE", NULL);
+      ATL_Cassert(sscanf(ln, " %d %d %d %d %d %lf %s \"%[^\"]", &j, &i, &mu,
+                         &nu, &il1mul, &mf, ln3, tnam) == 8, "R1TUNE", NULL);
       fclose(fp);
-      fprintf(fpsum,
-              "      ger : chose routine %s written by %s\n", ln3, tnam);
-      fprintf(fpsum,
+      ATL_mprintf(2, fpsum, stdout,
+              "      ger : chose routine %d:%s written by %s\n", j, ln3, tnam);
+      ATL_mprintf(2, fpsum, stdout,
               "            mu=%d, nu=%d, using %5.2f%% of L1 Cache\n",
-              mu, nu, l1mul*100.0);
-      fprintf(fpsum,
-"              Performance = %.2f (%5.2f%% of copy matmul, %5.2f%% of peak)\n",
-              mf, (mf/mmmf)*100.0, (mf / mfp)*100.0);
-      fprintf(stdout,
-              "      ger : chose routine %s written by %s\n", ln3, tnam);
-      fprintf(stdout,
-              "            mu=%d, nu=%d, using %5.2f%% of L1 Cache\n",
-              mu, nu, l1mul*100.0);
-      fprintf(stdout,
+              mu, nu, il1mul*0.01);
+      ATL_mprintf(2, fpsum, stdout,
 "              Performance = %.2f (%5.2f%% of copy matmul, %5.2f%% of peak)\n",
               mf, (mf/mmmf)*100.0, (mf / mfp)*100.0);
    }
