@@ -1,5 +1,5 @@
 /*
- *             Automatically Tuned Linear Algebra Software v3.3.7
+ *             Automatically Tuned Linear Algebra Software v3.3.15
  **************** THIS IS AN UNSUPPORTED DEVELOPER RELEASE *****************
  *                    (C) Copyright 1999 R. Clint Whaley
  *
@@ -11,10 +11,9 @@
  *   2. Redistributions in binary form must reproduce the above copyright
  *      notice, this list of conditions, and the following disclaimer in the
  *      documentation and/or other materials provided with the distribution.
- *   3. The name of the University of Tennessee, the ATLAS group,
- *      or the names of its contributers may not be used to endorse
- *      or promote products derived from this software without specific
- *      written permission.
+ *   3. The name of the ATLAS group or the names of its contributers may
+ *      not be used to endorse or promote products derived from this
+ *      software without specific written permission.
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
@@ -375,7 +374,7 @@ static TYPE llttest(enum ATLAS_UPLO Uplo, int CacheSize, int N, int lda,
 int RunCase(int CacheSize, TYPE thresh, int MFLOP, enum ATLAS_UPLO Uplo,
             int N, int lda)
 {
-   char *Ups;
+   char *Ups, *Ord;
    TYPE resid = 0.0;
    double mflop, mflops, t0, tim=0.0;
    int nreps=1, passed, i, imem;
@@ -390,7 +389,8 @@ int RunCase(int CacheSize, TYPE thresh, int MFLOP, enum ATLAS_UPLO Uplo,
    #endif
    mflops /= 1000000.0;
 
-   if (thresh > ATL_rzero) resid = llttest(Uplo, CacheSize, N, lda, &tim);
+   if (thresh > ATL_rzero) resid =
+      llttest(Uplo, CacheSize, N, lda, &tim);
    else resid = -1.0;
 
    if (MFLOP > mflops || thresh <= ATL_rzero) /* need to time repetitively */
@@ -406,7 +406,8 @@ int RunCase(int CacheSize, TYPE thresh, int MFLOP, enum ATLAS_UPLO Uplo,
       {
          for (i=0; i < imem; i++) lltgen(Uplo, N, A+i*incA, lda, N*1029+lda);
          t0 = time00();
-         for (i=nreps; i; i--, a += incA) test_potrf(Uplo, N, a, lda);
+         for (i=nreps; i; i--, a += incA)
+            test_potrf(Uplo, N, a, lda);
          tim = time00() - t0;
          tim /= nreps;
          free(A);
@@ -463,7 +464,7 @@ void GetFlags(int nargs, char **args, int *MFLOP, int *CacheSize, TYPE *thresh,
               int *ldagap, int *nuplo, enum ATLAS_UPLO **Uplo,
               int *N0, int *NN, int *incN)
 {
-   int i, j;
+   int i, j, n;
    char ch;
 
    *MFLOP = 0;
@@ -472,7 +473,7 @@ void GetFlags(int nargs, char **args, int *MFLOP, int *CacheSize, TYPE *thresh,
    #else
       *CacheSize = 4*1024*1024;
    #endif
-   *thresh = 10.0;
+   *thresh = 100.0;
    *N0 = *NN = *incN = -1;
    *ldagap = 0;
    *nuplo = -1;
