@@ -1,5 +1,5 @@
 /*
- *             Automatically Tuned Linear Algebra Software v3.3.7
+ *             Automatically Tuned Linear Algebra Software v3.3.15
  **************** THIS IS AN UNSUPPORTED DEVELOPER RELEASE *****************
  *                    (C) Copyright 1999 R. Clint Whaley
  *
@@ -11,10 +11,9 @@
  *   2. Redistributions in binary form must reproduce the above copyright
  *      notice, this list of conditions, and the following disclaimer in the
  *      documentation and/or other materials provided with the distribution.
- *   3. The name of the University of Tennessee, the ATLAS group,
- *      or the names of its contributers may not be used to endorse
- *      or promote products derived from this software without specific
- *      written permission.
+ *   3. The name of the ATLAS group or the names of its contributers may
+ *      not be used to endorse or promote products derived from this
+ *      software without specific written permission.
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
@@ -41,6 +40,10 @@
 void ATL_sger1_a1_x1_yX
    (const int M, const int N, const float alpha, const float *X,
     const int incX, const float *Y, const int incY, float *A, const int lda);
+void ATL_sgemvS_a1_x1_bX_y1
+   (const int M, const int N, const float alpha, const float *A,
+    const int lda, const float *X, const int incX, const float beta,
+    float *Y, const int incY);
 void ATL_sgemvT_a1_x1_bX_y1
    (const int M, const int N, const float alpha, const float *A,
     const int lda, const float *X, const int incX, const float beta,
@@ -49,6 +52,10 @@ void ATL_sgemvN_a1_x1_bX_y1
    (const int M, const int N, const float alpha, const float *A,
     const int lda, const float *X, const int incX, const float beta,
     float *Y, const int incY);
+void ATL_sgemvS_a1_x1_b1_y1
+   (const int M, const int N, const float alpha, const float *A,
+    const int lda, const float *X, const int incX, const float beta,
+    float *Y, const int incY);
 void ATL_sgemvT_a1_x1_b1_y1
    (const int M, const int N, const float alpha, const float *A,
     const int lda, const float *X, const int incX, const float beta,
@@ -57,6 +64,10 @@ void ATL_sgemvN_a1_x1_b1_y1
    (const int M, const int N, const float alpha, const float *A,
     const int lda, const float *X, const int incX, const float beta,
     float *Y, const int incY);
+void ATL_sgemvS_a1_x1_b0_y1
+   (const int M, const int N, const float alpha, const float *A,
+    const int lda, const float *X, const int incX, const float beta,
+    float *Y, const int incY);
 void ATL_sgemvT_a1_x1_b0_y1
    (const int M, const int N, const float alpha, const float *A,
     const int lda, const float *X, const int incX, const float beta,
@@ -68,6 +79,10 @@ void ATL_sgemvN_a1_x1_b0_y1
 void ATL_dger1_a1_x1_yX
    (const int M, const int N, const double alpha, const double *X,
     const int incX, const double *Y, const int incY, double *A, const int lda);
+void ATL_dgemvS_a1_x1_bX_y1
+   (const int M, const int N, const double alpha, const double *A,
+    const int lda, const double *X, const int incX, const double beta,
+    double *Y, const int incY);
 void ATL_dgemvT_a1_x1_bX_y1
    (const int M, const int N, const double alpha, const double *A,
     const int lda, const double *X, const int incX, const double beta,
@@ -76,6 +91,10 @@ void ATL_dgemvN_a1_x1_bX_y1
    (const int M, const int N, const double alpha, const double *A,
     const int lda, const double *X, const int incX, const double beta,
     double *Y, const int incY);
+void ATL_dgemvS_a1_x1_b1_y1
+   (const int M, const int N, const double alpha, const double *A,
+    const int lda, const double *X, const int incX, const double beta,
+    double *Y, const int incY);
 void ATL_dgemvT_a1_x1_b1_y1
    (const int M, const int N, const double alpha, const double *A,
     const int lda, const double *X, const int incX, const double beta,
@@ -84,6 +103,10 @@ void ATL_dgemvN_a1_x1_b1_y1
    (const int M, const int N, const double alpha, const double *A,
     const int lda, const double *X, const int incX, const double beta,
     double *Y, const int incY);
+void ATL_dgemvS_a1_x1_b0_y1
+   (const int M, const int N, const double alpha, const double *A,
+    const int lda, const double *X, const int incX, const double beta,
+    double *Y, const int incY);
 void ATL_dgemvT_a1_x1_b0_y1
    (const int M, const int N, const double alpha, const double *A,
     const int lda, const double *X, const int incX, const double beta,
@@ -102,6 +125,10 @@ void ATL_cger1u_a1_x1_yX
 void ATL_cger1c_a1_x1_yX
    (const int M, const int N, const float *alpha, const float *X,
     const int incX, const float *Y, const int incY, float *A, const int lda);
+void ATL_cgemvS_a1_x1_bXi0_y1
+   (const int M, const int N, const float *alpha, const float *A,
+    const int lda, const float *X, const int incX, const float *beta,
+    float *Y, const int incY);
 void ATL_cgemvC_a1_x1_bXi0_y1
    (const int M, const int N, const float *alpha, const float *A,
     const int lda, const float *X, const int incX, const float *beta,
@@ -118,6 +145,10 @@ void ATL_cgemvN_a1_x1_bXi0_y1
    (const int M, const int N, const float *alpha, const float *A,
     const int lda, const float *X, const int incX, const float *beta,
     float *Y, const int incY);
+void ATL_cgemvS_a1_x1_bX_y1
+   (const int M, const int N, const float *alpha, const float *A,
+    const int lda, const float *X, const int incX, const float *beta,
+    float *Y, const int incY);
 void ATL_cgemvC_a1_x1_bX_y1
    (const int M, const int N, const float *alpha, const float *A,
     const int lda, const float *X, const int incX, const float *beta,
@@ -134,6 +165,10 @@ void ATL_cgemvN_a1_x1_bX_y1
    (const int M, const int N, const float *alpha, const float *A,
     const int lda, const float *X, const int incX, const float *beta,
     float *Y, const int incY);
+void ATL_cgemvS_a1_x1_b1_y1
+   (const int M, const int N, const float *alpha, const float *A,
+    const int lda, const float *X, const int incX, const float *beta,
+    float *Y, const int incY);
 void ATL_cgemvC_a1_x1_b1_y1
    (const int M, const int N, const float *alpha, const float *A,
     const int lda, const float *X, const int incX, const float *beta,
@@ -150,6 +185,10 @@ void ATL_cgemvN_a1_x1_b1_y1
    (const int M, const int N, const float *alpha, const float *A,
     const int lda, const float *X, const int incX, const float *beta,
     float *Y, const int incY);
+void ATL_cgemvS_a1_x1_b0_y1
+   (const int M, const int N, const float *alpha, const float *A,
+    const int lda, const float *X, const int incX, const float *beta,
+    float *Y, const int incY);
 void ATL_cgemvC_a1_x1_b0_y1
    (const int M, const int N, const float *alpha, const float *A,
     const int lda, const float *X, const int incX, const float *beta,
@@ -172,6 +211,10 @@ void ATL_zger1u_a1_x1_yX
 void ATL_zger1c_a1_x1_yX
    (const int M, const int N, const double *alpha, const double *X,
     const int incX, const double *Y, const int incY, double *A, const int lda);
+void ATL_zgemvS_a1_x1_bXi0_y1
+   (const int M, const int N, const double *alpha, const double *A,
+    const int lda, const double *X, const int incX, const double *beta,
+    double *Y, const int incY);
 void ATL_zgemvC_a1_x1_bXi0_y1
    (const int M, const int N, const double *alpha, const double *A,
     const int lda, const double *X, const int incX, const double *beta,
@@ -188,6 +231,10 @@ void ATL_zgemvN_a1_x1_bXi0_y1
    (const int M, const int N, const double *alpha, const double *A,
     const int lda, const double *X, const int incX, const double *beta,
     double *Y, const int incY);
+void ATL_zgemvS_a1_x1_bX_y1
+   (const int M, const int N, const double *alpha, const double *A,
+    const int lda, const double *X, const int incX, const double *beta,
+    double *Y, const int incY);
 void ATL_zgemvC_a1_x1_bX_y1
    (const int M, const int N, const double *alpha, const double *A,
     const int lda, const double *X, const int incX, const double *beta,
@@ -204,6 +251,10 @@ void ATL_zgemvN_a1_x1_bX_y1
    (const int M, const int N, const double *alpha, const double *A,
     const int lda, const double *X, const int incX, const double *beta,
     double *Y, const int incY);
+void ATL_zgemvS_a1_x1_b1_y1
+   (const int M, const int N, const double *alpha, const double *A,
+    const int lda, const double *X, const int incX, const double *beta,
+    double *Y, const int incY);
 void ATL_zgemvC_a1_x1_b1_y1
    (const int M, const int N, const double *alpha, const double *A,
     const int lda, const double *X, const int incX, const double *beta,
@@ -220,6 +271,10 @@ void ATL_zgemvN_a1_x1_b1_y1
    (const int M, const int N, const double *alpha, const double *A,
     const int lda, const double *X, const int incX, const double *beta,
     double *Y, const int incY);
+void ATL_zgemvS_a1_x1_b0_y1
+   (const int M, const int N, const double *alpha, const double *A,
+    const int lda, const double *X, const int incX, const double *beta,
+    double *Y, const int incY);
 void ATL_zgemvC_a1_x1_b0_y1
    (const int M, const int N, const double *alpha, const double *A,
     const int lda, const double *X, const int incX, const double *beta,
