@@ -1,5 +1,5 @@
 /*
- *             Automatically Tuned Linear Algebra Software v3.3.7
+ *             Automatically Tuned Linear Algebra Software v3.3.15
  **************** THIS IS AN UNSUPPORTED DEVELOPER RELEASE *****************
  *                    (C) Copyright 1997 R. Clint Whaley
  *
@@ -11,10 +11,9 @@
  *   2. Redistributions in binary form must reproduce the above copyright
  *      notice, this list of conditions, and the following disclaimer in the
  *      documentation and/or other materials provided with the distribution.
- *   3. The name of the University of Tennessee, the ATLAS group,
- *      or the names of its contributers may not be used to endorse
- *      or promote products derived from this software without specific
- *      written permission.
+ *   3. The name of the ATLAS group or the names of its contributers may
+ *      not be used to endorse or promote products derived from this
+ *      software without specific written permission.
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
@@ -308,7 +307,7 @@
 #endif
 
 #define ATL_AlignPtr(vp) \
-   (void*) (ATL_Cachelen + ATL_MulByCachelen(ATL_DivByCachelen((size_t) (vp))));
+   (void*) (ATL_Cachelen + ATL_MulByCachelen(ATL_DivByCachelen((size_t) (vp))))
 
 #define ATL_FindPtrAdjust(vp, iadj_) \
 { \
@@ -330,6 +329,27 @@
    else (iadj_) = 0; \
 }
 
+/*
+ * Find N necessary for alignment.  Written as function for optimization,
+ * declared static to encourage inlining
+ */
+static int ATL_AlignOffset
+(const int N,       /* max return value */
+ const void *vp,    /* pointer to be aligned */
+ const int inc,     /* size of each elt, in bytes */
+ const int align)   /* required alignment, in bytes */
+{
+   const int p = align/inc;
+   const size_t k=(size_t)vp, j=k/inc;
+   int iret;
+   if (k == (j)*inc && p*inc == align)
+   {
+      iret = ((j+p-1) / p)*p - j;
+      if (iret <= N) return(iret);
+   }
+   return(N);
+}
+
 /*
  * Gcc links in crap that MSVC++ and DVF can't handle if you use stdout
  * or stderr, so use this beautiful kludge to avoid this problem -- RCW
