@@ -23,16 +23,7 @@
  * ATL_pfl1WO(mem) : fetch location mem to L1, with intent to write ONLY
  */
 
-#if defined(ATL_SSE1) || defined (ATL_SSE2) /* SSE prefetch is available */
-   #ifdef __GNUC__
-      #define ATL_pfl1R(mem) \
-         __asm__ __volatile__ ("prefetchnta %0" : : "m" (*((char *)(mem))))
-      #define ATL_pfl1W(mem) \
-         __asm__ __volatile__ ("prefetchnta %0" : : "m" (*((char *)(mem))))
-      #define ATL_pfl1WO ATL_pfl1W
-      #define ATL_GOT_L1PREFETCH
-   #endif
-#elif defined(ATL_3DNow1) || defined(ATL_3DNow2)
+#if defined(ATL_3DNow1) || defined(ATL_3DNow2) || ( defined(ATL_SSE1) && defined(ATL_ARCH_ATHLON) )
    #ifdef __GNUC__
       #define ATL_pfl1R(mem) \
          __asm__ __volatile__ ("prefetch %0" : : "m" (*((char *)(mem))))
@@ -40,6 +31,30 @@
          __asm__ __volatile__ ("prefetchw %0" : : "m" (*((char *)(mem))))
       #define ATL_pfl1WO ATL_pfl1W
       #define ATL_GOT_L1PREFETCH
+      #ifdef ATL_SSE1
+         #define ATL_pfl2R(mem) \
+            __asm__ __volatile__ ("prefetcht1 %0" : : "m" (*((char *)(mem))))
+         #define ATL_pfl2W(mem) \
+            __asm__ __volatile__ ("prefetcht1 %0" : : "m" (*((char *)(mem))))
+         #define ATL_pfl2WO ATL_pfl2W
+         #define ATL_GOT_L2PREFETCH
+      #endif
+   #endif
+#elif defined(ATL_SSE1) || defined (ATL_SSE2) /* SSE prefetch is available */
+   #ifdef __GNUC__
+      #define ATL_pfl1R(mem) \
+         __asm__ __volatile__ ("prefetchnta %0" : : "m" (*((char *)(mem))))
+      #define ATL_pfl1W(mem) \
+         __asm__ __volatile__ ("prefetchnta %0" : : "m" (*((char *)(mem))))
+      #define ATL_pfl1WO ATL_pfl1W
+      #define ATL_GOT_L1PREFETCH
+
+      #define ATL_pfl2R(mem) \
+         __asm__ __volatile__ ("prefetcht1 %0" : : "m" (*((char *)(mem))))
+      #define ATL_pfl2W(mem) \
+         __asm__ __volatile__ ("prefetcht1 %0" : : "m" (*((char *)(mem))))
+      #define ATL_pfl2WO ATL_pfl2W
+      #define ATL_GOT_L2PREFETCH
    #endif
 #elif defined(ATL_ARCH_21264)
    #ifdef __GNUC__
@@ -69,9 +84,12 @@
       #define ATL_GOT_L1PREFETCH
    #endif
 #elif defined(ATL_ARCH_IA64Itan)
+/*
+ * Have to use nt2, 'cause fpu ignored L1.
+ */
    #ifdef __GNUC__
       #define ATL_pfl1R(mem) \
-         __asm__ ("    lfetch  [%0]": : "r"((void *)(mem)))
+         __asm__ ("    lfetch.nt2  [%0]": : "r"((void *)(mem)))
       #define ATL_pfl1W(mem) \
          __asm__ ("    lfetch.excl     [%0]": : "r"((void *)(mem)))
       #define ATL_GOT_L1PREFETCH
@@ -87,10 +105,31 @@
 #if defined(ATL_pfl1W) && !defined(ATL_pfl1WO)
    #define ATL_pfl1WO ATL_pfl1W
 #endif
+
+#ifdef ATL_NOL1PREFETCH
+   #ifdef ATL_GOT_L1PREFETCH
+      #undef ATL_pfl1R
+      #undef ATL_pfl1W
+      #undef ATL_pfl1WO
+      #undef ATL_GOT_L1PREFETCH
+   #endif
+#endif
+#ifdef ATL_NOL2PREFETCH
+   #ifdef ATL_GOT_L2PREFETCH
+      #undef ATL_pfl2R
+      #undef ATL_pfl2W
+      #undef ATL_pfl2WO
+      #undef ATL_GOT_L2PREFETCH
+   #endif
+#endif
 #ifndef ATL_GOT_L1PREFETCH  /* dummy calls cpp takes out of code */
    #define ATL_pfl1R(mem)
    #define ATL_pfl1W(mem)
    #define ATL_pfl1WO(mem)
 #endif
+#ifndef ATL_GOT_L2PREFETCH  /* dummy calls cpp takes out of code */
+   #define ATL_pfl2R(mem)
+   #define ATL_pfl2W(mem)
+#endif
 
 #endif
