@@ -1,5 +1,5 @@
 /*
- *             Automatically Tuned Linear Algebra Software v3.3.7
+ *             Automatically Tuned Linear Algebra Software v3.3.15
  **************** THIS IS AN UNSUPPORTED DEVELOPER RELEASE *****************
  *                    (C) Copyright 1999 R. Clint Whaley
  *
@@ -13,10 +13,9 @@
  *   2. Redistributions in binary form must reproduce the above copyright
  *      notice, this list of conditions, and the following disclaimer in the
  *      documentation and/or other materials provided with the distribution.
- *   3. The name of the University of Tennessee, the ATLAS group,
- *      or the names of its contributers may not be used to endorse
- *      or promote products derived from this software without specific
- *      written permission.
+ *   3. The name of the ATLAS group or the names of its contributers may
+ *      not be used to endorse or promote products derived from this
+ *      software without specific written permission.
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
@@ -51,12 +50,16 @@ double time00();
    #define dumb_rand() ( 0.5 - ((double)rand())/((double)RAND_MAX) )
 #endif
 
+void ATL_ststsqtran(const int N, float *A, const int lda);
 void ATL_sgeprint
    (char *mat, const int M, const int N, const float *A, const int lda);
 
 float ATL_sgediffnrm1
    (const int M, const int N, const float *A, const int lda,
     const float *B, const int ldb);
+float ATL_shediffnrm
+   (const enum ATLAS_ORDER Order, const enum ATLAS_UPLO Uplo, const int N,
+    const float *A0, const int ld0, const float *A1, const int ld1);
 float ATL_sinfnrm(const int N, const float *X, const int incX);
 float ATL_sgenrm1
    (const int M, const int N, const float *A, const int lda);
@@ -98,12 +101,16 @@ void ATL_svdiff(const int N, const float *X, const int incX,
                 const float *Y, const int incY, float *Z, const int incZ);
 void ATL_sgediff(const int M, const int N, const float *A, const int lda,
                  const float *B, const int ldb, float *C, const int ldc);
+void ATL_dtstsqtran(const int N, double *A, const int lda);
 void ATL_dgeprint
    (char *mat, const int M, const int N, const double *A, const int lda);
 
 double ATL_dgediffnrm1
    (const int M, const int N, const double *A, const int lda,
     const double *B, const int ldb);
+double ATL_dhediffnrm
+   (const enum ATLAS_ORDER Order, const enum ATLAS_UPLO Uplo, const int N,
+    const double *A0, const int ld0, const double *A1, const int ld1);
 double ATL_dinfnrm(const int N, const double *X, const int incX);
 double ATL_dgenrm1
    (const int M, const int N, const double *A, const int lda);
@@ -145,12 +152,16 @@ void ATL_dvdiff(const int N, const double *X, const int incX,
                 const double *Y, const int incY, double *Z, const int incZ);
 void ATL_dgediff(const int M, const int N, const double *A, const int lda,
                  const double *B, const int ldb, double *C, const int ldc);
+void ATL_ctstsqtran(const int N, float *A, const int lda);
 void ATL_cgeprint
    (char *mat, const int M, const int N, const float *A, const int lda);
 
 float ATL_cgediffnrm1
    (const int M, const int N, const float *A, const int lda,
     const float *B, const int ldb);
+float ATL_chediffnrm
+   (const enum ATLAS_ORDER Order, const enum ATLAS_UPLO Uplo, const int N,
+    const float *A0, const int ld0, const float *A1, const int ld1);
 float ATL_cinfnrm(const int N, const float *X, const int incX);
 float ATL_cgenrm1
    (const int M, const int N, const float *A, const int lda);
@@ -192,12 +203,16 @@ void ATL_cvdiff(const int N, const float *X, const int incX,
                 const float *Y, const int incY, float *Z, const int incZ);
 void ATL_cgediff(const int M, const int N, const float *A, const int lda,
                  const float *B, const int ldb, float *C, const int ldc);
+void ATL_ztstsqtran(const int N, double *A, const int lda);
 void ATL_zgeprint
    (char *mat, const int M, const int N, const double *A, const int lda);
 
 double ATL_zgediffnrm1
    (const int M, const int N, const double *A, const int lda,
     const double *B, const int ldb);
+double ATL_zhediffnrm
+   (const enum ATLAS_ORDER Order, const enum ATLAS_UPLO Uplo, const int N,
+    const double *A0, const int ld0, const double *A1, const int ld1);
 double ATL_zinfnrm(const int N, const double *X, const int incX);
 double ATL_zgenrm1
    (const int M, const int N, const double *A, const int lda);
@@ -240,6 +255,45 @@ void ATL_zvdiff(const int N, const double *X, const int incX,
 void ATL_zgediff(const int M, const int N, const double *A, const int lda,
                  const double *B, const int ldb, double *C, const int ldc);
 
+/*
+ * Wrappers so that C can call F77 LAPACK
+ */
+int ATL_sf77getri
+   (const enum ATLAS_ORDER, const int, float*, const int, int*,
+    float*, int*);
+int ATL_sf77getrf
+   (const enum ATLAS_ORDER, const int, const int, float*, const int, int*);
+int ATL_sf77potrf(const enum ATLAS_UPLO, const int, float*, const int);
+int ATL_sf77lauum(const enum ATLAS_UPLO, const int, float*, const int);
+int ATL_sf77trtri(const enum ATLAS_UPLO, const enum ATLAS_DIAG, const int,
+                  float*, const int);
+int ATL_df77getri
+   (const enum ATLAS_ORDER, const int, double*, const int, int*,
+    double*, int*);
+int ATL_df77getrf
+   (const enum ATLAS_ORDER, const int, const int, double*, const int, int*);
+int ATL_df77potrf(const enum ATLAS_UPLO, const int, double*, const int);
+int ATL_df77lauum(const enum ATLAS_UPLO, const int, double*, const int);
+int ATL_df77trtri(const enum ATLAS_UPLO, const enum ATLAS_DIAG, const int,
+                  double*, const int);
+int ATL_cf77getri
+   (const enum ATLAS_ORDER, const int, float*, const int, int*,
+    float*, int*);
+int ATL_cf77getrf
+   (const enum ATLAS_ORDER, const int, const int, float*, const int, int*);
+int ATL_cf77potrf(const enum ATLAS_UPLO, const int, float*, const int);
+int ATL_cf77lauum(const enum ATLAS_UPLO, const int, float*, const int);
+int ATL_cf77trtri(const enum ATLAS_UPLO, const enum ATLAS_DIAG, const int,
+                  float*, const int);
+int ATL_zf77getri
+   (const enum ATLAS_ORDER, const int, double*, const int, int*,
+    double*, int*);
+int ATL_zf77getrf
+   (const enum ATLAS_ORDER, const int, const int, double*, const int, int*);
+int ATL_zf77potrf(const enum ATLAS_UPLO, const int, double*, const int);
+int ATL_zf77lauum(const enum ATLAS_UPLO, const int, double*, const int);
+int ATL_zf77trtri(const enum ATLAS_UPLO, const enum ATLAS_DIAG, const int,
+                  double*, const int);
 /*
  * =====================================================================
  * Prototypes for C-callable F77 interface to the Level 1 BLAS routines
