@@ -1,5 +1,5 @@
 /*
- *             Automatically Tuned Linear Algebra Software v3.3.7
+ *             Automatically Tuned Linear Algebra Software v3.3.15
  **************** THIS IS AN UNSUPPORTED DEVELOPER RELEASE *****************
  *                    (C) Copyright 1999 R. Clint Whaley
  *
@@ -11,10 +11,9 @@
  *   2. Redistributions in binary form must reproduce the above copyright
  *      notice, this list of conditions, and the following disclaimer in the
  *      documentation and/or other materials provided with the distribution.
- *   3. The name of the University of Tennessee, the ATLAS group,
- *      or the names of its contributers may not be used to endorse
- *      or promote products derived from this software without specific
- *      written permission.
+ *   3. The name of the ATLAS group or the names of its contributers may
+ *      not be used to endorse or promote products derived from this
+ *      software without specific written permission.
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
@@ -40,18 +39,24 @@ int clapack_sgesv(const enum CBLAS_ORDER Order, const int N, const int NRHS,
                   float *B, const int ldb);
 int clapack_sgetrf(const enum CBLAS_ORDER Order, const int M, const int N,
                    float *A, const int lda, int *ipiv);
-void clapack_sgetrs
+int clapack_sgetrs
    (const enum CBLAS_ORDER Order, const enum CBLAS_TRANSPOSE Trans,
     const int N, const int NRHS, const float *A, const int lda,
     const int *ipiv, float *B, const int ldb);
+int clapack_sgetri(const enum CBLAS_ORDER Order, const int N, float *A,
+                   const int lda, const int *ipiv);
 int clapack_sposv(const enum ATLAS_ORDER Order, const enum ATLAS_UPLO Uplo,
                   const int N, const int NRHS, float *A, const int lda,
                   float *B, const int ldb);
 int clapack_spotrf(const enum ATLAS_ORDER Order, const enum ATLAS_UPLO Uplo,
                    const int N, float *A, const int lda);
-void clapack_spotrs(const enum CBLAS_ORDER Order, const enum CBLAS_UPLO Uplo,
-                    const int N, const int NRHS, const float *A, const int lda,
-                    float *B, const int ldb);
+int clapack_spotrs(const enum CBLAS_ORDER Order, const enum CBLAS_UPLO Uplo,
+                   const int N, const int NRHS, const float *A, const int lda,
+                   float *B, const int ldb);
+int clapack_spotri(const enum ATLAS_ORDER Order, const enum ATLAS_UPLO Uplo,
+                   const int N, float *A, const int lda);
+int clapack_slauum(const enum ATLAS_ORDER Order, const enum ATLAS_UPLO Uplo,
+                   const int N, float *A, const int lda);
 int clapack_strtri(const enum ATLAS_ORDER Order,const enum ATLAS_UPLO Uplo,
                   const enum ATLAS_DIAG Diag,const int N, float *A, const int lda);
 
@@ -60,18 +65,24 @@ int clapack_dgesv(const enum CBLAS_ORDER Order, const int N, const int NRHS,
                   double *B, const int ldb);
 int clapack_dgetrf(const enum CBLAS_ORDER Order, const int M, const int N,
                    double *A, const int lda, int *ipiv);
-void clapack_dgetrs
+int clapack_dgetrs
    (const enum CBLAS_ORDER Order, const enum CBLAS_TRANSPOSE Trans,
     const int N, const int NRHS, const double *A, const int lda,
     const int *ipiv, double *B, const int ldb);
+int clapack_dgetri(const enum CBLAS_ORDER Order, const int N, double *A,
+                   const int lda, const int *ipiv);
 int clapack_dposv(const enum ATLAS_ORDER Order, const enum ATLAS_UPLO Uplo,
                   const int N, const int NRHS, double *A, const int lda,
                   double *B, const int ldb);
 int clapack_dpotrf(const enum ATLAS_ORDER Order, const enum ATLAS_UPLO Uplo,
                    const int N, double *A, const int lda);
-void clapack_dpotrs(const enum CBLAS_ORDER Order, const enum CBLAS_UPLO Uplo,
-                    const int N, const int NRHS, const double *A, const int lda,
-                    double *B, const int ldb);
+int clapack_dpotrs(const enum CBLAS_ORDER Order, const enum CBLAS_UPLO Uplo,
+                   const int N, const int NRHS, const double *A, const int lda,
+                   double *B, const int ldb);
+int clapack_dpotri(const enum ATLAS_ORDER Order, const enum ATLAS_UPLO Uplo,
+                   const int N, double *A, const int lda);
+int clapack_dlauum(const enum ATLAS_ORDER Order, const enum ATLAS_UPLO Uplo,
+                   const int N, double *A, const int lda);
 int clapack_dtrtri(const enum ATLAS_ORDER Order,const enum ATLAS_UPLO Uplo,
                   const enum ATLAS_DIAG Diag,const int N, double *A, const int lda);
 
@@ -80,18 +91,24 @@ int clapack_cgesv(const enum CBLAS_ORDER Order, const int N, const int NRHS,
                   void *B, const int ldb);
 int clapack_cgetrf(const enum CBLAS_ORDER Order, const int M, const int N,
                    void *A, const int lda, int *ipiv);
-void clapack_cgetrs
+int clapack_cgetrs
    (const enum CBLAS_ORDER Order, const enum CBLAS_TRANSPOSE Trans,
     const int N, const int NRHS, const void *A, const int lda,
     const int *ipiv, void *B, const int ldb);
+int clapack_cgetri(const enum CBLAS_ORDER Order, const int N, void *A,
+                   const int lda, const int *ipiv);
 int clapack_cposv(const enum ATLAS_ORDER Order, const enum ATLAS_UPLO Uplo,
                   const int N, const int NRHS, void *A, const int lda,
                   void *B, const int ldb);
 int clapack_cpotrf(const enum ATLAS_ORDER Order, const enum ATLAS_UPLO Uplo,
                    const int N, void *A, const int lda);
-void clapack_cpotrs(const enum CBLAS_ORDER Order, const enum CBLAS_UPLO Uplo,
-                    const int N, const int NRHS, const void *A, const int lda,
-                    void *B, const int ldb);
+int clapack_cpotrs(const enum CBLAS_ORDER Order, const enum CBLAS_UPLO Uplo,
+                   const int N, const int NRHS, const void *A, const int lda,
+                   void *B, const int ldb);
+int clapack_cpotri(const enum ATLAS_ORDER Order, const enum ATLAS_UPLO Uplo,
+                   const int N, void *A, const int lda);
+int clapack_clauum(const enum ATLAS_ORDER Order, const enum ATLAS_UPLO Uplo,
+                   const int N, void *A, const int lda);
 int clapack_ctrtri(const enum ATLAS_ORDER Order,const enum ATLAS_UPLO Uplo,
                   const enum ATLAS_DIAG Diag,const int N, void *A, const int lda);
 
@@ -100,18 +117,24 @@ int clapack_zgesv(const enum CBLAS_ORDER Order, const int N, const int NRHS,
                   void *B, const int ldb);
 int clapack_zgetrf(const enum CBLAS_ORDER Order, const int M, const int N,
                    void *A, const int lda, int *ipiv);
-void clapack_zgetrs
+int clapack_zgetrs
    (const enum CBLAS_ORDER Order, const enum CBLAS_TRANSPOSE Trans,
     const int N, const int NRHS, const void *A, const int lda,
     const int *ipiv, void *B, const int ldb);
+int clapack_zgetri(const enum CBLAS_ORDER Order, const int N, void *A,
+                   const int lda, const int *ipiv);
 int clapack_zposv(const enum ATLAS_ORDER Order, const enum ATLAS_UPLO Uplo,
                   const int N, const int NRHS, void *A, const int lda,
                   void *B, const int ldb);
 int clapack_zpotrf(const enum ATLAS_ORDER Order, const enum ATLAS_UPLO Uplo,
                    const int N, void *A, const int lda);
-void clapack_zpotrs(const enum CBLAS_ORDER Order, const enum CBLAS_UPLO Uplo,
-                    const int N, const int NRHS, const void *A, const int lda,
-                    void *B, const int ldb);
+int clapack_zpotrs(const enum CBLAS_ORDER Order, const enum CBLAS_UPLO Uplo,
+                   const int N, const int NRHS, const void *A, const int lda,
+                   void *B, const int ldb);
+int clapack_zpotri(const enum ATLAS_ORDER Order, const enum ATLAS_UPLO Uplo,
+                   const int N, void *A, const int lda);
+int clapack_zlauum(const enum ATLAS_ORDER Order, const enum ATLAS_UPLO Uplo,
+                   const int N, void *A, const int lda);
 int clapack_ztrtri(const enum ATLAS_ORDER Order,const enum ATLAS_UPLO Uplo,
                   const enum ATLAS_DIAG Diag,const int N, void *A, const int lda);
 
