@@ -1,5 +1,5 @@
 /*
- *             Automatically Tuned Linear Algebra Software v3.3.7
+ *             Automatically Tuned Linear Algebra Software v3.3.15
  **************** THIS IS AN UNSUPPORTED DEVELOPER RELEASE *****************
  *                    (C) Copyright 1999 R. Clint Whaley
  *
@@ -13,10 +13,9 @@
  *   2. Redistributions in binary form must reproduce the above copyright
  *      notice, this list of conditions, and the following disclaimer in the
  *      documentation and/or other materials provided with the distribution.
- *   3. The name of the University of Tennessee, the ATLAS group,
- *      or the names of its contributers may not be used to endorse
- *      or promote products derived from this software without specific
- *      written permission.
+ *   3. The name of the ATLAS group or the names of its contributers may
+ *      not be used to endorse or promote products derived from this
+ *      software without specific written permission.
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
@@ -45,6 +44,8 @@
 #endif
 
 #ifdef Add_
+   #define F77WRAP_GETRI Mjoin(PFW,getri_)
+   #define F77WRAP_LAUUM Mjoin(PFW,lauum_)
    #define F77WRAP_TRTRI Mjoin(PFW,trtri_)
    #define F77WRAP_GETNB Mjoin(PFW,getnb_)
    #define F77WRAP_GETRS Mjoin(PFW,getrs_)
@@ -54,6 +55,8 @@
    #define F77WRAP_POTRF Mjoin(PFW,potrf_)
    #define F77WRAP_POSV Mjoin(PFW,posv_)
 #elif defined(Add__)
+   #define F77WRAP_GETRI Mjoin(PFW,getri__)
+   #define F77WRAP_LAUUM Mjoin(PFW,lauum__)
    #define F77WRAP_TRTRI Mjoin(PFW,trtri__)
    #define F77WRAP_GETNB Mjoin(PFW,getnb__)
    #define F77WRAP_GETRS Mjoin(PFW,getrs__)
@@ -63,6 +66,8 @@
    #define F77WRAP_POTRF Mjoin(PFW,potrf__)
    #define F77WRAP_POSV Mjoin(PFW,posv__)
 #elif defined(NoChange)
+   #define F77WRAP_GETRI Mjoin(PFW,getri)
+   #define F77WRAP_LAUUM Mjoin(PFW,lauum)
    #define F77WRAP_TRTRI Mjoin(PFW,trtri)
    #define F77WRAP_GETNB Mjoin(PFW,getnb)
    #define F77WRAP_GETRS Mjoin(PFW,getrs)
@@ -72,6 +77,8 @@
    #define F77WRAP_POTRF Mjoin(PFW,potrf)
    #define F77WRAP_POSV Mjoin(PFW,posv)
 #elif defined(UpCase)
+   #define F77WRAP_GETRI Mjoin(PFW,GETRI)
+   #define F77WRAP_LAUUM Mjoin(PFW,LAUUM)
    #define F77WRAP_TRTRI Mjoin(PFW,TRTRI)
    #define F77WRAP_GETNB Mjoin(PFW,GETNB)
    #define F77WRAP_GETRS Mjoin(PFW,GETRS)
