@@ -1,5 +1,5 @@
 /*
- *             Automatically Tuned Linear Algebra Software v3.3.7
+ *             Automatically Tuned Linear Algebra Software v3.3.15
  **************** THIS IS AN UNSUPPORTED DEVELOPER RELEASE *****************
  *                    (C) Copyright 1999 R. Clint Whaley
  *
@@ -11,10 +11,9 @@
  *   2. Redistributions in binary form must reproduce the above copyright
  *      notice, this list of conditions, and the following disclaimer in the
  *      documentation and/or other materials provided with the distribution.
- *   3. The name of the University of Tennessee, the ATLAS group,
- *      or the names of its contributers may not be used to endorse
- *      or promote products derived from this software without specific
- *      written permission.
+ *   3. The name of the ATLAS group or the names of its contributers may
+ *      not be used to endorse or promote products derived from this
+ *      software without specific written permission.
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
@@ -52,24 +51,38 @@ int clapack_cgesv(const enum CBLAS_ORDER Order, const int N, const int NRHS,
    int ierr = 0;
 
    if (Order != CblasRowMajor && Order != CblasColMajor)
+   {
+      ierr = -1;
       cblas_xerbla(1, "clapack_cgesv",
                    "Order must be %d or %d, but is set to %d.\n",
                    CblasRowMajor, CblasColMajor, Order);
+   }
    if (N < 0)
+   {
+      ierr = -2;
       cblas_xerbla(2, "clapack_cgesv",
                    "N cannot be less than zero 0,; is set to %d.\n", N);
+   }
    if (NRHS < 0)
+   {
+      ierr = -3;
       cblas_xerbla(3, "clapack_cgesv",
                    "NRHS cannot be less than zero 0,; is set to %d.\n", NRHS);
+   }
    if (lda < N || lda < 1)
+   {
+      ierr = -5;
       cblas_xerbla(5, "clapack_cgesv",
                    "lda must be >= MAX(N,1): lda=%d N=%d\n", lda, N);
+   }
    if (ldb < N || ldb < 1)
+   {
+      ierr = -8;
       cblas_xerbla(8, "clapack_cgesv",
                    "ldb must be >= MAX(N,1): ldb=%d N=%d\n", ldb, N);
 
-   ierr = ATL_cgetrf(Order, N, N, A, lda, ipiv);
-   if (ierr == 0)
-      ATL_cgetrs(Order, CblasNoTrans, N, NRHS, A, lda, ipiv, B, ldb);
+   }
+   if (!ierr) ierr = ATL_cgetrf(Order, N, N, A, lda, ipiv);
+   if (!ierr) ATL_cgetrs(Order, CblasNoTrans, N, NRHS, A, lda, ipiv, B, ldb);
    return(ierr);
 }
