@@ -1,5 +1,5 @@
 /*
- *             Automatically Tuned Linear Algebra Software v3.3.7
+ *             Automatically Tuned Linear Algebra Software v3.3.15
  **************** THIS IS AN UNSUPPORTED DEVELOPER RELEASE *****************
  *                    (C) Copyright 1999 R. Clint Whaley
  *
@@ -11,10 +11,9 @@
  *   2. Redistributions in binary form must reproduce the above copyright
  *      notice, this list of conditions, and the following disclaimer in the
  *      documentation and/or other materials provided with the distribution.
- *   3. The name of the University of Tennessee, the ATLAS group,
- *      or the names of its contributers may not be used to endorse
- *      or promote products derived from this software without specific
- *      written permission.
+ *   3. The name of the ATLAS group or the names of its contributers may
+ *      not be used to endorse or promote products derived from this
+ *      software without specific written permission.
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
@@ -70,28 +69,45 @@ int clapack_cgetrf(const enum CBLAS_ORDER Order, const int M, const int N,
  *       occur if it is used to solve a system of equations.
  */
 {
+   int ierr=0;
    if (Order != CblasRowMajor && Order != CblasColMajor)
+   {
+      ierr = -1;
       cblas_xerbla(1, "clapack_cgetrf",
                    "Order must be %d or %d, but is set to %d\n",
                    CblasRowMajor, CblasColMajor, Order);
+   }
    if (M < 0)
+   {
+      ierr = -2;
       cblas_xerbla(2, "clapack_cgetrf",
                    "M cannot be less than zero 0,; is set to %d.\n", M);
+   }
    if (N < 0)
+   {
+      ierr = -3;
       cblas_xerbla(3, "clapack_cgetrf",
                    "N cannot be less than zero 0,; is set to %d.\n", N);
+   }
    if (Order == CblasColMajor)
    {
       if (lda < M || lda < 1)
+      {
+         ierr = -6;
          cblas_xerbla(6, "clapack_cgetrf",
                       "lda must be >= MAX(M,1): lda=%d M=%d\n", lda, M);
+      }
    }
    else
    {
       if (lda < N || lda < 1)
+      {
+         ierr = -6;
          cblas_xerbla(6, "clapack_cgetrf",
                       "lda must be >= MAX(N,1): lda=%d N=%d\n", lda, N);
+      }
    }
-   return(ATL_getrf(Order, M, N, A, lda, ipiv));
+   if (!ierr) ierr = ATL_getrf(Order, M, N, A, lda, ipiv);
+   return(ierr);
 }
 
