@@ -1,5 +1,5 @@
 /*
- *             Automatically Tuned Linear Algebra Software v3.3.7
+ *             Automatically Tuned Linear Algebra Software v3.3.15
  **************** THIS IS AN UNSUPPORTED DEVELOPER RELEASE *****************
  *                    (C) Copyright 1999 R. Clint Whaley
  *
@@ -11,10 +11,9 @@
  *   2. Redistributions in binary form must reproduce the above copyright
  *      notice, this list of conditions, and the following disclaimer in the
  *      documentation and/or other materials provided with the distribution.
- *   3. The name of the University of Tennessee, the ATLAS group,
- *      or the names of its contributers may not be used to endorse
- *      or promote products derived from this software without specific
- *      written permission.
+ *   3. The name of the ATLAS group or the names of its contributers may
+ *      not be used to endorse or promote products derived from this
+ *      software without specific written permission.
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
@@ -38,19 +37,33 @@
 int clapack_dpotrf(const enum ATLAS_ORDER Order, const enum ATLAS_UPLO Uplo,
                    const int N, double *A, const int lda)
 {
+   int ierr=0;
    if (Order != CblasRowMajor && Order != CblasColMajor)
+   {
+      ierr = -1;
       cblas_xerbla(1, "clapack_dpotrf",
                    "Order must be %d or %d, but is set to %d\n",
                    CblasRowMajor, CblasColMajor, Order);
+   }
    if (Uplo != CblasUpper && Uplo != CblasLower)
+   {
+      ierr = -2;
       cblas_xerbla(2, "clapack_dpotrf",
                    "Uplo must be %d or %d, but is set to %d\n",
                    CblasUpper, CblasLower, Uplo);
+   }
    if (N < 0)
+   {
+      ierr = -3;
       cblas_xerbla(3, "clapack_dpotrf",
                    "N cannot be less than zero 0,; is set to %d.\n", N);
+   }
    if (lda < N || lda < 1)
+   {
+      ierr = -5;
       cblas_xerbla(5, "clapack_dpotrf",
                    "lda must be >= MAX(N,1): lda=%d N=%d\n", lda, N);
-   return(ATL_dpotrf(Order, Uplo, N, A, lda));
+   }
+   if (!ierr) ierr = ATL_dpotrf(Order, Uplo, N, A, lda);
+   return(ierr);
 }
