@@ -1,5 +1,5 @@
 /*
- *             Automatically Tuned Linear Algebra Software v3.3.7
+ *             Automatically Tuned Linear Algebra Software v3.3.15
  **************** THIS IS AN UNSUPPORTED DEVELOPER RELEASE *****************
  *                   (C) Copyright 2001 Peter Soendergaard
  *
@@ -13,10 +13,9 @@
  *   2. Redistributions in binary form must reproduce the above copyright
  *      notice, this list of conditions, and the following disclaimer in the
  *      documentation and/or other materials provided with the distribution.
- *   3. The name of the University of Tennessee, the ATLAS group,
- *      or the names of its contributers may not be used to endorse
- *      or promote products derived from this software without specific
- *      written permission.
+ *   3. The name of the ATLAS group or the names of its contributers may
+ *      not be used to endorse or promote products derived from this
+ *      software without specific written permission.
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
@@ -36,29 +35,44 @@
 #include "atlas_lapack.h"
 #include "clapack.h"
 
-int clapack_strtri(const enum ATLAS_ORDER Order,
-                        const enum ATLAS_UPLO Uplo,
-                        const enum ATLAS_DIAG Diag,
-                  const int N, float *A, const int lda)
+int clapack_strtri(const enum ATLAS_ORDER Order, const enum ATLAS_UPLO Uplo,
+                   const enum ATLAS_DIAG Diag, const int N,
+                   float *A, const int lda)
 {
+   int ierr;
    if (Order != CblasRowMajor && Order != CblasColMajor)
+   {
+      ierr = -1;
       cblas_xerbla(1, "clapack_strtri",
                    "Order must be %d or %d, but is set to %d\n",
                    CblasRowMajor, CblasColMajor, Order);
+   }
    if (Uplo != CblasUpper && Uplo != CblasLower)
+   {
+      ierr = -2;
       cblas_xerbla(2, "clapack_strtri",
                    "Uplo must be %d or %d, but is set to %d\n",
                    CblasUpper, CblasLower, Uplo);
+   }
    if (Diag != CblasUnit && Diag != CblasNonUnit)
+   {
+      ierr = -3;
       cblas_xerbla(3, "clapack_strtri",
                    "Diag must be %d or %d, but is set to %d\n",
                    CblasNonUnit, CblasUnit, Diag);
+   }
    if (N < 0)
+   {
+      ierr = -4;
       cblas_xerbla(4, "clapack_strtri",
                    "N cannot be less than zero 0,; is set to %d.\n", N);
+   }
    if (lda < N || lda < 1)
+   {
+      ierr = -6;
       cblas_xerbla(6, "clapack_strtri",
                    "lda must be >= MAX(N,1): lda=%d N=%d\n", lda, N);
-
-   return(ATL_strtri(Order, Uplo, Diag, N, A, lda));
+   }
+   if (ierr) ierr = ATL_strtri(Order, Uplo, Diag, N, A, lda);
+   return(ierr);
 }
