@@ -1,5 +1,5 @@
 /*
- *             Automatically Tuned Linear Algebra Software v3.3.7
+ *             Automatically Tuned Linear Algebra Software v3.3.15
  **************** THIS IS AN UNSUPPORTED DEVELOPER RELEASE *****************
  *                    (C) Copyright 1999 R. Clint Whaley
  *
@@ -11,10 +11,9 @@
  *   2. Redistributions in binary form must reproduce the above copyright
  *      notice, this list of conditions, and the following disclaimer in the
  *      documentation and/or other materials provided with the distribution.
- *   3. The name of the University of Tennessee, the ATLAS group,
- *      or the names of its contributers may not be used to endorse
- *      or promote products derived from this software without specific
- *      written permission.
+ *   3. The name of the ATLAS group or the names of its contributers may
+ *      not be used to endorse or promote products derived from this
+ *      software without specific written permission.
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
@@ -35,31 +34,50 @@
 #include "atlas_lapack.h"
 #include "clapack.h"
 
-void clapack_zgetrs
+int clapack_zgetrs
    (const enum CBLAS_ORDER Order, const enum CBLAS_TRANSPOSE Trans,
     const int N, const int NRHS, const void *A, const int lda,
     const int *ipiv, void *B, const int ldb)
 {
+   int ierr=0;
    if (Order != CblasRowMajor && Order != CblasColMajor)
+   {
+      ierr = -1;
       cblas_xerbla(1, "clapack_zgetrs",
                    "Order must be %d or %d, but is set to %d\n",
                    CblasRowMajor, CblasColMajor, Order);
+   }
    if (Trans != CblasNoTrans && Trans != CblasTrans && Trans != CblasConjTrans)
+   {
+      ierr = -2;
       cblas_xerbla(2, "clapack_zgetrs",
                    "Trans must be %d, %d, or %d, but is set to %d\n",
                    CblasNoTrans, CblasTrans, CblasConjTrans);
+   }
    if (N < 0)
+   {
+      ierr = -3;
       cblas_xerbla(3, "clapack_zgetrs",
                    "N cannot be less than zero 0,; is set to %d.\n", N);
+   }
    if (NRHS < 0)
+   {
+      ierr = -4;
       cblas_xerbla(4, "clapack_zgetrs",
                    "NRHS cannot be less than zero 0,; is set to %d.\n", NRHS);
+   }
    if (lda < N || lda < 1)
+   {
+      ierr = -6;
       cblas_xerbla(6, "clapack_zgetrs",
                    "lda must be >= MAX(N,1): lda=%d N=%d\n", lda, N);
+   }
    if (ldb < N || ldb < 1)
+   {
+      ierr = -9;
       cblas_xerbla(9, "clapack_zgetrs",
                    "ldb must be >= MAX(N,1): lda=%d N=%d\n", lda, N);
-
-   ATL_zgetrs(Order, Trans, N, NRHS, A, lda, ipiv, B, ldb);
+   }
+   if (!ierr) ATL_zgetrs(Order, Trans, N, NRHS, A, lda, ipiv, B, ldb);
+   return(ierr);
 }
