@@ -1,5 +1,5 @@
 /*
- *             Automatically Tuned Linear Algebra Software v3.3.7
+ *             Automatically Tuned Linear Algebra Software v3.3.15
  **************** THIS IS AN UNSUPPORTED DEVELOPER RELEASE *****************
  *                    (C) Copyright 1997 R. Clint Whaley
  *
@@ -11,10 +11,9 @@
  *   2. Redistributions in binary form must reproduce the above copyright
  *      notice, this list of conditions, and the following disclaimer in the
  *      documentation and/or other materials provided with the distribution.
- *   3. The name of the University of Tennessee, the ATLAS group,
- *      or the names of its contributers may not be used to endorse
- *      or promote products derived from this software without specific
- *      written permission.
+ *   3. The name of the ATLAS group or the names of its contributers may
+ *      not be used to endorse or promote products derived from this
+ *      software without specific written permission.
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
@@ -228,7 +227,8 @@ void Mjoin(Mjoin(PATL,aliased_gemm),TATB)
  *    See if it is possible to avoid copying A
  */
       #if !defined(NoTransA_) && defined(TREAL)
-         if ( lda == NB && K == NB && SCALAR_IS_ONE(alpha) ) pA = (TYPE *) A;
+         if ( !AC_aliased && lda == NB && K == NB && SCALAR_IS_ONE(alpha) )
+            pA = (TYPE *) A;
          else
          {
       #endif
@@ -310,7 +310,8 @@ void Mjoin(Mjoin(PATL,aliased_gemm),TATB)
  *    See if it is possible to avoid copying B
  */
       #if defined(NoTransB_) && defined(TREAL)
-         if (ldb == NB && K == NB && alpha == 1.0) pB = (TYPE *) B;
+         if (!BC_aliased && ldb == NB && K == NB && alpha == 1.0)
+            pB = (TYPE *) B;
          else
          {
       #endif
