@@ -1,5 +1,5 @@
 /*
- *             Automatically Tuned Linear Algebra Software v3.3.7
+ *             Automatically Tuned Linear Algebra Software v3.3.15
  **************** THIS IS AN UNSUPPORTED DEVELOPER RELEASE *****************
  *                    (C) Copyright 1997 R. Clint Whaley
  *
@@ -11,10 +11,9 @@
  *   2. Redistributions in binary form must reproduce the above copyright
  *      notice, this list of conditions, and the following disclaimer in the
  *      documentation and/or other materials provided with the distribution.
- *   3. The name of the University of Tennessee, the ATLAS group,
- *      or the names of its contributers may not be used to endorse
- *      or promote products derived from this software without specific
- *      written permission.
+ *   3. The name of the ATLAS group or the names of its contributers may
+ *      not be used to endorse or promote products derived from this
+ *      software without specific written permission.
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
@@ -134,13 +133,20 @@ void Mjoin(Mjoin(PATL,syr2k_putU),BNM)
             A[j2+1] = ATL_MulByBETA(A[j2+1]) + Dc[j2+1] + Dc[j2+1];
          #endif
       #else
-         for (i=0; i <= j2; i += 2, Dr += ldD2)
+         for (i=0; i != j2; i += 2, Dr += ldD2)
          {
-            ra = A[i];
-            ia = A[i+1];
+            ra = A[i]; ia = A[i+1];
             A[i] = ra*rbeta - ia*ibeta + Dc[i] + *Dr;
             A[i+1] = rbeta*ia + ibeta*ra + Dc[i+1] + Dr[1];
          }
+         #ifdef Herm_
+            A[j2] = A[j2]*rbeta + 2.0*Dc[j2];
+            A[j2+1] = ATL_rzero;
+         #else
+            ra = A[j2]; ia = A[j2+1];
+            A[j2] = ra*rbeta - ia*ibeta + 2.0*Dc[j2];
+            A[j2+1] = rbeta*ia + ibeta*ra + 2.0*Dc[j2+1];
+         #endif
       #endif
       A += lda2;
       Dc += ldD2;
